.. currentmodule:: plopp

*****************
Pythreejs backend
*****************

.. autosummary::
   :toctree: generated

   backends.pythreejs.PythreejsBackend
   backends.pythreejs.canvas.Canvas
   backends.pythreejs.outline.Outline
   backends.pythreejs.point_cloud.PointCloud
   backends.pythreejs.figure.Figure
